import 'package:flutter/foundation.dart';

class NPlatform {
  const NPlatform._(this.string);
  final String string;

  static const NPlatform android = NPlatform._('android');
  static const NPlatform ios = NPlatform._('ios');
  static const NPlatform web = NPlatform._('web');
  static const NPlatform macos = NPlatform._('macos');
  static const NPlatform windows = NPlatform._('windows');
  static const NPlatform linux = NPlatform._('linux');
  static const NPlatform fuchsia = NPlatform._('fuchsia');

  static bool get isWeb => kIsWeb;
  static bool get isMacOs => !kIsWeb && defaultTargetPlatform == TargetPlatform.macOS;
  static bool get isWindows => !kIsWeb && defaultTargetPlatform == TargetPlatform.windows;
  static bool get isLinux => !kIsWeb && defaultTargetPlatform == TargetPlatform.linux;
  static bool get isAndroid => !kIsWeb && defaultTargetPlatform == TargetPlatform.android;
  static bool get isIOS => !kIsWeb && defaultTargetPlatform == TargetPlatform.iOS;
  static bool get isDesktop => isMacOs || isWindows || isLinux;

  static NPlatform get currentPlatform {
    if (isWeb) return web;
    switch (defaultTargetPlatform) {
      case TargetPlatform.android:
        return android;
      case TargetPlatform.fuchsia:
        return fuchsia;
      case TargetPlatform.iOS:
        return ios;
      case TargetPlatform.linux:
        return linux;
      case TargetPlatform.macOS:
        return macos;
      case TargetPlatform.windows:
        return windows;
    }
  }
}
