import 'package:chewie/chewie.dart';
import 'package:flutter/material.dart';
import 'package:nowa_runtime/nowa_runtime.dart';
import 'package:video_player/video_player.dart';

class NowaVideoPlayerController {
  NowaVideoPlayerController({
    required this.url,
    required this.type,
    this.autoPlay = false,
    this.showControlsBar = true,
    this.allowFullScreenButton = true,
  });

  final String type;
  final String? url;
  final bool autoPlay;
  final bool showControlsBar;
  final bool allowFullScreenButton;

  late VideoPlayerController? _videoPlayerController;
  ChewieController? _chewieController;

  ChewieController? get chewieController => _chewieController;

  Future<bool> initialize(BuildContext context) async {
    if (url == null) {
      return false;
    }

    if (!NPlatform.isDesktop) {
      if (type == 'asset') {
        _videoPlayerController = VideoPlayerController.asset(url!);
      } else {
        _videoPlayerController = VideoPlayerController.networkUrl(Uri.parse(url!));
      }
    }

    await _videoPlayerController!.initialize();

    _chewieController = ChewieController(
      videoPlayerController: _videoPlayerController!,
      autoPlay: autoPlay,
      showControls: showControlsBar,
      allowFullScreen: allowFullScreenButton,
    );
    return true;
  }

  void dispose() {
    if (!NPlatform.isWeb && !NPlatform.isDesktop) {
      _videoPlayerController!.dispose();
    }
  }
}
